;; Generated package description from ace-window.el  -*- no-byte-compile: t -*-
(define-package "ace-window" "0.10.0.0.20211228.180009" "Quickly switch windows." '((avy "0.5.0")) :commit "0577c426a9833ab107bab46c60d1885c611b2fb9" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Oleh Krehel" . "ohwoeowho@gmail.com") :keywords '("window" "location") :url "https://github.com/abo-abo/ace-window")
